@@ -14,6 +14,8 @@
 	There's always a deadlock. --ThOr
 */
 
+#include "out123_int.h"
+
 #include <math.h>
 
 #include <jack/jack.h>
@@ -24,7 +26,6 @@
 #include <semaphore.h>
 #include <sys/errno.h>
 
-#include "out123_int.h"
 #include "debug.h"
 
 typedef struct {
@@ -304,7 +305,7 @@ static int connect_jack_ports(out123_handle *ao
 				++wish_channels;
 		debug1("wish_channels: %i", wish_channels);
 		wishlist = malloc(sizeof(char*)*(wish_channels+1));
-		devcopy = strdup(ao->device);
+		devcopy = compat_strdup(ao->device);
 		if(devcopy == NULL || wishlist == NULL)
 		{
 			if(devcopy)
@@ -521,7 +522,7 @@ static int open_jack(out123_handle *ao)
 	}
 
 	debug("Jack open successful.\n");
-	ao->realname = strdup(realname);
+	ao->realname = compat_strdup(realname);
 	return 0;
 }
 
